{% extends 'wiki/base.html' %} {% load i18n %} {% block title %} {% trans "History for" %} {{ article.title }} {% endblock %} {% block content %}

# {{ article.title }}

## {% trans "Article History" %}

{% trans "At" %} | {% trans "User" %} | {% trans "Comment" %} | {% trans "Revert" %}
--- | --- | --- | ---
{% for change in changes %}
{{ change.modified|date:"M d, Y" }} | {% if change.is_anonymous_change %} {{ change.editor_ip }} {% else %} {{ change.editor }} {% endif %} | {% if change.comment %}'{{ change.comment}}' {% endif %} | {% if forloop.first %} {% trans "Current revision" %} {% else %} {% endif %}
{% endfor %}

Atom Feed {% endblock %}